@@ -55,7 +55,8 @@ void ProviderWindow::refreshProviders() {
         }
         row++;
     }
-    qDebug() << "Providers added";
+    ui->tblProviders->resizeRowsToContents();
+    qDebug() << "Providers refreshed";
 }
 
 void ProviderWindow::changeEvent(QEvent *e)
